'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var videojs = _interopDefault(require('video.js'));

var version = "0.0.0";

// Default options for the plugin.
var defaults = {};

// Cross-compatibility for Video.js 5 and 6.
var registerPlugin = videojs.registerPlugin || videojs.plugin;
// const dom = videojs.dom || videojs;

/**
 * Function to invoke when the player is ready.
 *
 * This is a great place for your plugin to initialize itself. When this
 * function is called, the player will have its DOM and child components
 * in place.
 *
 * @function onPlayerReady
 * @param    {Player} player
 *           A Video.js player object.
 *
 * @param    {Object} [options={}]
 *           A plain object containing options for the plugin.
 */
var onPlayerReady = function onPlayerReady(player, options) {
  // player.addClass('vjs-social-media');
  var links = options.links;
  var Component = videojs.getComponent('Component');
  var menuLinks = new Component(player);
  var CompButton = new Component(player);

  // Create Button
  var button = CompButton.createEl('div', {
    className: 'vjs-button-social'
  });

  button.addEventListener('click', function (e) {
    var el = document.getElementsByClassName('vjs-menu-social')[0];

    this.classList.toggle('open');
    el.classList.toggle('show');
    e.stopPropagation();
  });

  button.addEventListener('touchend', function (e) {
    e.stopPropagation();
  });

  // Create Menu
  var menu = menuLinks.createEl('div', {
    className: 'vjs-menu-social'
  });

  menu.addEventListener('touchend', function (e) {
    e.stopPropagation();
  });

  for (var _iterator = links, _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
    var _ref;

    if (_isArray) {
      if (_i >= _iterator.length) break;
      _ref = _iterator[_i++];
    } else {
      _i = _iterator.next();
      if (_i.done) break;
      _ref = _i.value;
    }

    var elem = _ref;

    createComponentSocial(elem);
  }

  function createComponentSocial(elem) {
    var item = new Component(player).createEl('span', {
      className: 'vjs-icon-' + elem.name
    });

    var url = '';

    switch (elem.name) {
      case 'facebook':
        url = 'http://www.facebook.com/sharer.php?u=' + elem.url;

        if (typeof elem.title !== 'undefined') {
          url += '&title=' + elem.title;
        }

        if (typeof elem.summary !== 'undefined') {
          url += '&summary=' + elem.summary;
        }

        break;

      case 'gplus':
        url = 'https://plus.google.com/share?url=' + elem.url;
        break;

      case 'tumblr':
        url = 'http://tumblr.com/widgets/share/tool?canonicalUrl=' + elem.url;
        break;

      case 'pinterest':
        url = 'https://pinterest.com/pin/create/button/?url=' + elem.url;

        if (typeof elem.summary !== 'undefined') {
          url += '&description=' + elem.summary;
        }

        break;
      case 'twitter':
        url = 'https://twitter.com/intent/tweet?url=' + elem.url;

        if (typeof elem.text !== 'undefined') {
          url += '&text=' + elem.text;
        }

        if (typeof elem.via !== 'undefined') {
          url += '&via=' + elem.via;
        }

        if (typeof elem.related !== 'undefined') {
          url += '&related=' + elem.related;
        }

        if (typeof elem.hashtags !== 'undefined') {
          url += '&hashtags=' + elem.hashtags;
        }

        break;
      case 'linkedin':
        url = 'https://www.linkedin.com/shareArticle?mini=true&url=' + elem.url;

        if (typeof elem.title !== 'undefined') {
          url += '&title=' + elem.title;
        }

        if (typeof elem.summary !== 'undefined') {
          url += '&summary=' + elem.summary;
        }

        break;
    }
    // window.open(encodeURIComponent(url));
    item.addEventListener('click', function () {
      return window.open(url);
    });

    menu.appendChild(item);
  }

  menuLinks.el_ = menu;
  CompButton.el_ = button;

  player.addChild(menuLinks);
  player.addChild(CompButton);
};

/**
 * A video.js plugin.
 *
 * In the plugin function, the value of `this` is a video.js `Player`
 * instance. You cannot rely on the player being in a "ready" state here,
 * depending on how the plugin is invoked. This may or may not be important
 * to you; if not, remove the wait for "ready"!
 *
 * @function socialMedia
 * @param    {Object} [options={}]
 *           An object of options left to the plugin author to define.
 */
var socialMedia = function socialMedia(options) {
  var _this = this;

  this.ready(function () {
    onPlayerReady(_this, videojs.mergeOptions(defaults, options));
  });
};

// Register the plugin with video.js.
registerPlugin('socialMedia', socialMedia);

// Include the version number.
socialMedia.VERSION = version;

module.exports = socialMedia;
